crypto

package
v0.0.0-...-753fb36 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecryptStream

func DecryptStream(reader io.Reader, writer io.Writer, password string) error

DecryptStream decrypts data from reader and writes to writer.

func EncryptStream

func EncryptStream(reader io.Reader, writer io.Writer, password string) error

EncryptStream encrypts data from reader and writes to writer using AES-256-GCM.

Types

This section is empty.

Jump to